@@ -170,6 +170,7 @@ class CombineArchiveContentFormat(str, enum.Enum):
     NEURON_SESSION = 'http://purl.org/NET/mediatypes/text/x-nrn-ses'
     NMODL = 'http://purl.org/NET/mediatypes/text/x-nmodl'
     NuML = 'http://purl.org/NET/mediatypes/application/numl+xml'
+    ODE = 'http://purl.org/NET/mediatypes/text/x-ode'
     ODT = 'http://purl.org/NET/mediatypes/application/vnd.oasis.opendocument.text'
     OMEX = 'http://identifiers.org/combine.specifications/omex'
     OMEX_MANIFEST = 'http://identifiers.org/combine.specifications/omex-manifest'
@@ -214,9 +215,9 @@ class CombineArchiveContentFormat(str, enum.Enum):
     Vega_Lite = 'http://purl.org/NET/mediatypes/application/vnd.vegalite.v3+json'
     WEBP = 'http://purl.org/NET/mediatypes/image/webp'
     XML = 'http://purl.org/NET/mediatypes/application/xml'
-    XPP = 'http://purl.org/NET/mediatypes/text/x-xpp'
-    XPP_AUTO = 'http://purl.org/NET/mediatypes/text/x-xpp-auto'
-    XPP_SET = 'http://purl.org/NET/mediatypes/text/x-xpp-set'
+    XPP = 'http://purl.org/NET/mediatypes/text/x-ode'
+    XPP_AUTO = 'http://purl.org/NET/mediatypes/text/x-ode-auto'
+    XPP_SET = 'http://purl.org/NET/mediatypes/text/x-ode-set'
     XLS = 'http://purl.org/NET/mediatypes/application/vnd.ms-excel'
     XLSX = 'http://purl.org/NET/mediatypes/application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
     XSL = 'http://purl.org/NET/mediatypes/application/xslfo+xml'
@@ -288,6 +289,7 @@ class CombineArchiveContentFormatPattern(str, enum.Enum):
     NEURON_SESSION = r'^https?://purl\.org/NET/mediatypes/text/x-nrn-ses$'
     NMODL = r'^https?://purl\.org/NET/mediatypes/text/x-nmodl$'
     NuML = r'^https?://purl\.org/NET/mediatypes/application/numl\+xml$'
+    ODE = r'^https?://purl\.org/NET/mediatypes/text/x-(ode|xpp)$'
     ODT = r'^https?://purl\.org/NET/mediatypes/application/vnd\.oasis\.opendocument\.text$'
     OMEX = r'^https?://identifiers\.org/combine\.specifications/omex($|\.)'
     OMEX_MANIFEST = r'^https?://identifiers\.org/combine\.specifications/omex-manifest($|\.)'
@@ -344,9 +346,9 @@ class CombineArchiveContentFormatPattern(str, enum.Enum):
     XLS = r'^https?://purl\.org/NET/mediatypes/application/vnd\.ms-excel$'
     XLSX = r'^https?://purl\.org/NET/mediatypes/application/vnd\.openxmlformats-officedocument\.spreadsheetml\.sheet$'
     XML = r'^https?://purl\.org/NET/mediatypes/application/xml$'
-    XPP = r'^https?://purl\.org/NET/mediatypes/text/x-xpp$'
-    XPP_AUTO = r'^https?://purl\.org/NET/mediatypes/text/x-xpp-auto$'
-    XPP_SET = r'^https?://purl\.org/NET/mediatypes/text/x-xpp-set$'
+    XPP = r'^https?://purl\.org/NET/mediatypes/text/x-(ode|xpp)$'
+    XPP_AUTO = r'^https?://purl\.org/NET/mediatypes/text/x-(ode|xpp)-auto$'
+    XPP_SET = r'^https?://purl\.org/NET/mediatypes/text/x-(ode|xpp)-set$'
     XSL = r'^https?://purl\.org/NET/mediatypes/(application/xslfo\+xml|text/xsl)$'
     XUL = r'^https?://purl\.org/NET/mediatypes/text/xul$'
     XYZ = r'^https?://purl\.org/NET/mediatypes/chemical/x-xyz$'
