@@ -15,9 +15,10 @@ from ...sedml.data_model import (  # noqa: F401
     Task,
     )
 from ...utils.core import flatten_nested_list_of_strings
-from ...warnings import warn, BioSimulatorsWarning
 from .data_model import SIMULATION_METHOD_KISAO_MAP
 from .validation import validate_model
+import decimal
+import math
 import types  # noqa: F401
 
 __all__ = ['get_parameters_variables_outputs_for_simulation']
@@ -26,7 +27,7 @@ __all__ = ['get_parameters_variables_outputs_for_simulation']
 def get_parameters_variables_outputs_for_simulation(model_filename, model_language, simulation_type, algorithm_kisao_id=None,
                                                     set_filename=None, parameter_filename=None, initial_conditions_filename=None,
                                                     change_level=SedDocument, native_ids=False, native_data_types=False,
-                                                    config=None):
+                                                    config=None, max_number_of_steps=None):
     """ Get the possible observables for a simulation of a model
 
     Args:
@@ -44,6 +45,7 @@ def get_parameters_variables_outputs_for_simulation(model_filename, model_langua
             for the variable of an associated SED-ML data generator
         native_data_types (:obj:`bool`, optional): whether to return new_values in their native data types
         config (:obj:`Config`, optional): whether to fail on missing includes
+        max_number_of_steps (:obj:`int`, optional): maximum number of steps to record
 
     Returns:
         :obj:`list` of :obj:`ModelAttributeChange`: possible attributes of a model that can be changed and their default values
@@ -68,7 +70,7 @@ def get_parameters_variables_outputs_for_simulation(model_filename, model_langua
     # parameters
     params = []
 
-    for key, val in model['parameters'].items():
+    for key, val in (model.get('parameters', None) or {}).items():
         params.append(ModelAttributeChange(
             id=key if native_ids else 'parameter_{}'.format(key),
             name=None if native_ids else 'Value of parameter "{}"'.format(key),
@@ -76,16 +78,19 @@ def get_parameters_variables_outputs_for_simulation(model_filename, model_langua
             new_value=val if native_data_types else str(val),
         ))
 
-    for key, val in model['initial_conditions'].items():
-        params.append(ModelAttributeChange(
-            id=key if native_ids else 'initial_condition_{}'.format(key),
-            name=None if native_ids else 'Initial condition of "{}"'.format(key),
-            target='{}'.format(key),
-            new_value=val if native_data_types else str(val),
-        ))
+    aux_var_ids = [key.upper() for key in (model.get('auxiliary_variables', None) or {}).keys()]
+    for key, val in (model.get('initial_conditions', None) or {}).items():
+        if key.upper() not in aux_var_ids:
+            params.append(ModelAttributeChange(
+                id=key if native_ids else 'initial_condition_{}'.format(key),
+                name=None if native_ids else 'Initial condition of "{}"'.format(key),
+                target='{}'.format(key),
+                new_value=val if native_data_types else str(val),
+            ))
 
     # simulation
-    sim_method_id = model['simulation_method'].get('meth', 'rungekutta').lower()
+    simulation_method = model.get('simulation_method', None) or {}
+    sim_method_id = simulation_method.get('meth', 'rungekutta').lower()
     sim_method_props = SIMULATION_METHOD_KISAO_MAP[sim_method_id]
     sim_method_kisao_id = sim_method_props['kisao_id']
 
@@ -96,25 +101,42 @@ def get_parameters_variables_outputs_for_simulation(model_filename, model_langua
         )
     )
 
-    t_0 = float(model['simulation_method'].get('t0', 0.))
-    duration = float(model['simulation_method'].get('total', 20.))
-    d_t = float(model['simulation_method'].get('dt', 0.05))
-    n_jmp = float(model['simulation_method'].get('njmp', 1))
+    t_0 = float(simulation_method.get('t0', 0.))
+    t_output_start = float(simulation_method.get('trans', t_0))
+    duration = float(simulation_method.get('total', 20.))
+    d_t = float(simulation_method.get('dt', 0.05))
+    n_jmp = int(float(simulation_method.get('njmp', 1)))
+
+    if 'dt' not in sim_method_props['parameters']:
+        n_jmp = simulation_method['njmp'] = 1
 
     sim.initial_time = t_0
-    sim.output_start_time = t_0
-    sim.output_end_time = sim.initial_time + duration
-    sim.number_of_steps = duration / (d_t * n_jmp)
+    sim.output_start_time = t_output_start
+    sim.output_end_time = t_0 + duration
+    sim.number_of_steps = (sim.output_end_time - sim.output_start_time) / (d_t * n_jmp)
     sim.number_of_steps = round(sim.number_of_steps)
 
-    for key, val in model['simulation_method'].items():
+    if max_number_of_steps is not None and sim.number_of_steps > max_number_of_steps:
+        if 'dt' in sim_method_props['parameters']:
+            new_d_t = (sim.output_end_time - sim.output_start_time) / max_number_of_steps
+            n_jmp = math.ceil(new_d_t / d_t)
+        else:
+            n_jmp = 1
+        d_t = float(
+            (decimal.Decimal(sim.output_end_time) - decimal.Decimal(sim.output_start_time))
+            / decimal.Decimal(max_number_of_steps) / decimal.Decimal(n_jmp)
+        )
+        simulation_method['dt'] = str(d_t)
+        simulation_method['njmp'] = str(n_jmp)
+        sim.number_of_steps = max_number_of_steps
+
+    for key, val in simulation_method.items():
         param_kisao_id = sim_method_props['parameters'].get(key, None)
         if param_kisao_id:
             sim.algorithm.changes.append(AlgorithmParameterChange(kisao_id=param_kisao_id,
                                                                   new_value=float(val) if native_data_types else val))
 
     # observables
-    var_ids = set()
     vars = []
 
     time_variable = Variable(
@@ -124,53 +146,47 @@ def get_parameters_variables_outputs_for_simulation(model_filename, model_langua
     )
     vars.append(time_variable)
 
-    for key in model['initial_conditions'].keys():
+    for key in (model.get('initial_conditions', None) or {}).keys():
         var = Variable(
             id=key if native_ids else 'dynamics_{}'.format(key),
             name=None if native_ids else 'Dynamics of "{}"'.format(key),
             target=key,
         )
-        if var.id not in var_ids:
-            var_ids.add(var.id)
-            vars.append(var)
+        vars.append(var)
 
-    for key in model['auxiliary_variables'].keys():
+    for key in (model.get('auxiliary_variables', None) or {}).keys():
         var = Variable(
-            id=key if native_ids else 'dynamics_{}'.format(key),
+            id=key if native_ids else 'dynamics_aux_{}'.format(key),
             name=None if native_ids else 'Dynamics of "{}"'.format(key),
             target=key,
         )
-        if var.id not in var_ids:
-            var_ids.add(var.id)
-            vars.append(var)
+        vars.append(var)
 
     # plots
-    if 'elements' in model['plot']:
+    ode_plot = model.get('plot', None) or {}
+    if 'elements' in ode_plot:
         plot_type = Plot2D
-        for i_element in sorted(model['plot']['elements'].keys()):
-            element = model['plot']['elements'][i_element]
+        for i_element in sorted(ode_plot['elements'].keys()):
+            element = ode_plot['elements'][i_element]
             if 'z' in element:
                 plot_type = Plot3D
                 break
 
-        for i_element in sorted(model['plot']['elements'].keys()):
-            element = model['plot']['elements'][i_element]
+        for i_element in sorted(ode_plot['elements'].keys()):
+            element = ode_plot['elements'][i_element]
             if 'x' not in element:
-                element['x'] = 'T'
-                warn('Plot element {} does not declare x data. X data is assumed to be time (t).'.format(i_element + 1), BioSimulatorsWarning)
+                element['x'] = 'T'  # what XPP uses as the default
 
             if 'y' not in element:
-                element['y'] = 'T'
-                warn('Plot element {} does not declare y data. Y data is assumed to be time (t).'.format(i_element + 1), BioSimulatorsWarning)
+                element['y'] = 'T'  # what XPP uses as the default
 
             if plot_type == Plot3D:
                 if 'z' not in element:
-                    element['z'] = 'T'
-                    warn('3D plot element {} does not declare z data. Z data is assumed to be time (t).'.format(i_element + 1), BioSimulatorsWarning)
+                    element['z'] = 'T'  # what XPP uses as the default
 
         data_generators = {}
         for var in vars:
-            data_generators[var.target or 'T'] = DataGenerator(
+            data_generators[(var.target or 'T').upper()] = DataGenerator(
                 id='data_generator_{}'.format(var.target),
                 name=var.target,
                 variables=[var],
@@ -179,8 +195,8 @@ def get_parameters_variables_outputs_for_simulation(model_filename, model_langua
 
         plot = plot_type(id='plot')
 
-        for i_element in sorted(model['plot']['elements'].keys()):
-            element = model['plot']['elements'][i_element]
+        for i_element in sorted(ode_plot['elements'].keys()):
+            element = ode_plot['elements'][i_element]
 
             if plot_type == Plot2D:
                 plot.curves.append(Curve(
