@@ -11,7 +11,8 @@ from ..config import get_config, Config  # noqa: F401
 from .data_model import (Triple, OmexMetadataOutputFormat, OmexMetadataSchema,
                          BIOSIMULATIONS_ROOT_URI_PATTERN,
                          BIOSIMULATIONS_PREDICATE_TYPES,
-                         BIOSIMULATIONS_NAMESPACE_PREFIX_MAP)
+                         BIOSIMULATIONS_NAMESPACE_PREFIX_MAP,
+                         BIOSIMULATIONS_NAMESPACE_ALIASES)
 from .utils import get_local_combine_archive_content_uri, get_global_combine_archive_content_uri
 from .validation import validate_biosimulations_metadata
 from lxml import etree
@@ -340,7 +341,7 @@ class TriplesOmexMetaReader(OmexMetaReader):
 
             if temp_warnings:
                 if isinstance(filename_or_filenames, (tuple, list)):
-                    warnings.append(['The OMEX Metadata file at location `{}` may be invalid.'.format(error_filename), temp_warnings])
+                    warnings.append(['The OMEX Metadata file at location `{}` has warnings.'.format(error_filename), temp_warnings])
                 else:
                     warnings.extend(temp_warnings)
 
@@ -503,7 +504,7 @@ class BiosimulationsOmexMetaReader(OmexMetaReader):
 
             if temp_warnings:
                 if isinstance(filename_or_filenames, (tuple, list)):
-                    warnings.append(['The OMEX Metadata file at location `{}` may be invalid.'.format(error_filename), temp_warnings])
+                    warnings.append(['The OMEX Metadata file at location `{}` has warnings.'.format(error_filename), temp_warnings])
                 else:
                     warnings.extend(temp_warnings)
 
@@ -570,6 +571,24 @@ class BiosimulationsOmexMetaReader(OmexMetaReader):
         errors = []
         warnings = []
 
+        for triple in triples:
+            subject = str(triple.subject)
+            predicate = str(triple.predicate)
+            object = str(triple.object)
+
+            for ns, alias in BIOSIMULATIONS_NAMESPACE_ALIASES.items():
+                if isinstance(triple.subject, rdflib.term.URIRef) and subject.startswith(ns):
+                    subject = alias + subject[len(ns):]
+                    triple.subject = rdflib.term.URIRef(subject)
+
+                if isinstance(triple.predicate, rdflib.term.URIRef) and predicate.startswith(ns):
+                    predicate = alias + predicate[len(ns):]
+                    triple.predicate = rdflib.term.URIRef(predicate)
+
+                if isinstance(triple.object, rdflib.term.URIRef) and object.startswith(ns):
+                    object = alias + object[len(ns):]
+                    triple.object = rdflib.term.URIRef(object)
+
         objects = {}
         for triple in triples:
             for node, is_subject in [(triple.subject, True), (triple.object, False)]:
@@ -633,7 +652,7 @@ class BiosimulationsOmexMetaReader(OmexMetaReader):
                         }
                         for sub_el in el['value'].get('other', []):
                             if (
-                                sub_el['predicate'] == 'http://dublincore.org/specifications/dublin-core/dcmi-terms/identifier'
+                                sub_el['predicate'] == 'http://purl.org/dc/elements/1.1/identifier'
                                 and 'uri' in sub_el['value']
                             ):
                                 value['uri'] = sub_el['value']['uri']
@@ -710,13 +729,13 @@ class BiosimulationsOmexMetaReader(OmexMetaReader):
                 }
                 for el in other_md['value'].get('description', []):
                     if (
-                        el['predicate'] == 'http://dublincore.org/specifications/dublin-core/dcmi-terms/description'
+                        el['predicate'] == 'http://purl.org/dc/elements/1.1/description'
                         and 'label' in el['value']
                     ):
                         value['attribute']['label'] = el['value']['label']
                 for el in other_md['value'].get('other', []):
                     if (
-                        el['predicate'] == 'http://dublincore.org/specifications/dublin-core/dcmi-terms/identifier'
+                        el['predicate'] == 'http://purl.org/dc/elements/1.1/identifier'
                         and 'uri' in el['value']
                     ):
                         value['value']['uri'] = el['value']['uri']
@@ -775,7 +794,7 @@ class BiosimulationsOmexMetaWriter(OmexMetaWriter):
         local_id = 0
 
         namespaces = {
-            'dc': rdflib.Namespace('http://dublincore.org/specifications/dublin-core/dcmi-terms/'),
+            'dc': rdflib.Namespace('http://purl.org/dc/elements/1.1/'),
             'dcterms': rdflib.Namespace('http://purl.org/dc/terms/'),
             'foaf': rdflib.Namespace('http://xmlns.com/foaf/0.1/'),
             'rdfs': rdflib.Namespace('http://www.w3.org/2000/01/rdf-schema#'),
@@ -820,20 +839,33 @@ class BiosimulationsOmexMetaWriter(OmexMetaWriter):
                             ))
 
                         if predicate_type['uri'] in [
-                            'http://dublincore.org/specifications/dublin-core/dcmi-terms/creator',
-                            'http://dublincore.org/specifications/dublin-core/dcmi-terms/contributor',
+                            'http://purl.org/dc/elements/1.1/creator',
+                            'http://purl.org/dc/elements/1.1/contributor',
                         ]:
                             if value.get('uri', None) is not None:
-                                triples.append(Triple(
-                                    object,
-                                    namespaces['foaf'].accountName,
-                                    rdflib.term.URIRef(value['uri']
-                                                       .replace('http://identifiers.org/orcid:',
-                                                                'https://orcid.org/')
-                                                       .replace('https://identifiers.org/orcid:',
-                                                                'https://orcid.org/')
-                                                       )
-                                ))
+                                if value['uri'].lower().startswith('mailto:'):
+                                    triples.append(Triple(
+                                        object,
+                                        namespaces['foaf'].mbox,
+                                        rdflib.term.URIRef(value['uri'])
+                                    ))
+                                if value['uri'].lower().startswith('tel:'):
+                                    triples.append(Triple(
+                                        object,
+                                        namespaces['foaf'].phone,
+                                        rdflib.term.URIRef(value['uri'])
+                                    ))
+                                else:
+                                    triples.append(Triple(
+                                        object,
+                                        namespaces['foaf'].accountName,
+                                        rdflib.term.URIRef(value['uri']
+                                                           .replace('http://identifiers.org/orcid:',
+                                                                    'https://orcid.org/')
+                                                           .replace('https://identifiers.org/orcid:',
+                                                                    'https://orcid.org/')
+                                                           )
+                                    ))
 
                             if value.get('label', None) is not None:
                                 triples.append(Triple(
