@@ -11,13 +11,13 @@ from ..kisao.utils import get_term as get_kisao_term, get_term_type as get_kisao
 from ..xml.utils import validate_xpaths_ref_to_unique_objects, eval_xpath
 from .data_model import (SedIdGroupMixin, AbstractTask, Task, RepeatedTask,  # noqa: F401
                          Model, ModelLanguage, ModelLanguagePattern,
-                         ModelChange, ComputeModelChange,
+                         ModelChange, ComputeModelChange, ModelAttributeChange,
                          Simulation, OneStepSimulation, SteadyStateSimulation,
                          UniformTimeCourseSimulation, Algorithm, Variable,
                          Range, FunctionalRange, UniformRange, VectorRange,
                          SetValueComputeModelChange,
                          Report, Plot2D, Plot3D, DataGenerator,
-                         Calculation)
+                         Calculation, Style, LineStyleType, MarkerStyleType)
 from .math import compile_math, eval_math
 from .utils import (append_all_nested_children_to_doc, get_range_len,
                     is_model_language_encoded_in_xml,
@@ -25,7 +25,6 @@ from .utils import (append_all_nested_children_to_doc, get_range_len,
                     get_models_referenced_by_task,
                     get_all_sed_objects,
                     get_data_generators_for_output, get_variables_for_data_generators,
-                    get_model_changes_for_task,
                     get_task_results_shape)
 from kisao.data_model import TermType as KisaoTermType
 import collections
@@ -114,6 +113,43 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                     [[id] for id in repeated_ids],
                 ])
 
+    if validate_targets_with_model_sources:
+        has_xpath_model_changes = False
+        for model in doc.models:
+            if model.language and does_model_language_use_xpath_variable_targets(model.language):
+                has_xpath_model_changes = has_xpath_model_changes or model.has_structural_changes()
+        if has_xpath_model_changes:
+            msg = (
+                "This tool validates XPaths for model changes and variables against their unmodified target models. "
+                "As a result, this tool does not fully validate these XPaths. These XPaths could be invalidated by "
+                "changes to their target models."
+            )
+            warnings.append([msg])
+
+        model_etrees = {}
+        for model in doc.models:
+            if (
+                model.language
+                and is_model_language_encoded_in_xml(model.language)
+                and model.source
+                and not model.source.startswith('#')
+                and not model.source.startswith('urn:')
+                and not model.source.startswith('http://')
+                and not model.source.startswith('https://')
+            ):
+                if os.path.isabs(model.source):
+                    model_source = model.source
+                else:
+                    model_source = os.path.join(working_dir, model.source)
+
+                if os.path.isfile(model_source):
+                    try:
+                        model_etrees[model] = lxml.etree.parse(model_source)
+                    except Exception:
+                        pass
+    else:
+        model_etrees = {}
+
     if validate_semantics:
         errors.extend(validate_unique_ids(doc))
 
@@ -121,7 +157,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
         doc_copy = copy.deepcopy(doc)
         append_all_nested_children_to_doc(doc_copy)
 
-        for child_type in ('models', 'simulations', 'tasks', 'data_generators', 'outputs'):
+        for child_type in ('styles', 'models', 'simulations', 'tasks', 'data_generators', 'outputs'):
             not_children = set([child.id for child in getattr(doc_copy, child_type)]).difference(
                 set([child.id for child in getattr(doc, child_type)]))
             if not_children:
@@ -131,12 +167,30 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                     [[child] for child in sorted(not_children)],
                 ])
 
+        # styles
+        for i_style, style in enumerate(doc.styles):
+            style_errors, style_warnings = validate_style(style)
+
+            # append errors/warnings to global lists of errors and warnings
+            style_id = '`' + style.id + '`' if style and style.id else str(i_style + 1)
+
+            if style_errors:
+                errors.append(['Model {} is invalid.'.format(style_id), style_errors])
+
+            if style_warnings:
+                warnings.append(['Model {} has warnings.'.format(style_id), style_warnings])
+
+        # style bases are acyclic
+        errors.extend(validate_base_style_network(doc.styles))
+
         # model
         model_ids = [model.id for model in doc.models]
         for i_model, model in enumerate(doc.models):
+            model_etree = model_etrees.get(model, None)
             model_errors, model_warnings = validate_model(model, model_ids, working_dir,
                                                           validate_models_with_languages=validate_models_with_languages,
-                                                          config=config)
+                                                          check_in_model_source=validate_targets_with_model_sources,
+                                                          config=config, model_etree=model_etree)
 
             # append errors/warnings to global lists of errors and warnings
             model_id = '`' + model.id + '`' if model and model.id else str(i_model + 1)
@@ -145,7 +199,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                 errors.append(['Model {} is invalid.'.format(model_id), model_errors])
 
             if model_warnings:
-                warnings.append(['Model {} may be invalid.'.format(model_id), model_warnings])
+                warnings.append(['Model {} has warnings.'.format(model_id), model_warnings])
 
         # model sources are acyclic
         model_source_graph = networkx.DiGraph()
@@ -192,7 +246,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                 errors.append(['Simulation {} is invalid.'.format(sim_id), sim_errors])
             if sim_warnings:
                 sim_id = '`' + sim.id + '`' if sim and sim.id else str(i_sim + 1)
-                warnings.append(['Simulation {} may be invalid.'.format(sim_id), sim_warnings])
+                warnings.append(['Simulation {} has warnings.'.format(sim_id), sim_warnings])
 
         # basic tasks reference a model and a simulation
         task_errors = {}
@@ -299,10 +353,9 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                                 temp_errors, temp_warnings = validate_target(
                                     variable.target, variable.target_namespaces, Calculation,
                                     variable.model.language, variable.model.id,
-                                    check_in_model_source=(
-                                        not variable.model.changes
-                                        and not get_model_changes_for_task(task)
-                                    )
+                                    check_in_model_source=validate_targets_with_model_sources,
+                                    model_change=variable.model.has_structural_changes(),
+                                    model_etree=model_etrees.get(model, None),
                                 )
                                 variable_errors.extend(temp_errors)
                                 variable_warnings.extend(temp_warnings)
@@ -313,7 +366,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
 
                             if variable_warnings:
                                 variable_id = '`' + variable.id + '`' if variable and variable.id else str(i_variable + 1)
-                                range_warnings.append(['Variable {} may be invalid.'.format(variable_id), variable_warnings])
+                                range_warnings.append(['Variable {} has warnings.'.format(variable_id), variable_warnings])
 
                         temp_errors, temp_warnings = validate_calculation(range)
                         range_errors.extend(temp_errors)
@@ -336,7 +389,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                     if range_warnings:
                         range_id = '`' + range.id + '`' if range and range.id else str(i_range + 1)
                         task_warnings[task]['ranges'].append(
-                            ['{} {} may be invalid.'.format(range.__class__.__name__, range_id), range_warnings])
+                            ['{} {} has warnings.'.format(range.__class__.__name__, range_id), range_warnings])
 
         # ranges of repeated tasks have unique ids
         ranges_have_ids = True
@@ -450,7 +503,10 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                             temp_errors, temp_warnings = validate_target(
                                 change.target, change.target_namespaces,
                                 ModelChange, change.model.language, change.model.id,
-                                check_in_model_source=False)
+                                check_in_model_source=validate_targets_with_model_sources,
+                                model_change=change.model and change.model.has_structural_changes(),
+                                model_etree=model_etrees.get(model, None),
+                            )
                             change_errors.extend(temp_errors)
                             change_warnings.extend(temp_warnings)
 
@@ -489,7 +545,10 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                             temp_errors, temp_warnings = validate_target(
                                 variable.target, variable.target_namespaces,
                                 Calculation, variable.model.language, variable.model.id,
-                                check_in_model_source=False)
+                                check_in_model_source=validate_targets_with_model_sources,
+                                model_change=change.model and change.model.has_structural_changes(),
+                                model_etree=model_etrees.get(model, None),
+                            )
                             variable_errors.extend(temp_errors)
                             variable_warnings.extend(temp_warnings)
 
@@ -499,7 +558,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
 
                         if variable_warnings:
                             variable_id = '`' + variable.id + '`' if variable and variable.id else str(i_variable + 1)
-                            change_warnings.append(['Variable {} may be invalid.'.format(variable_id), variable_warnings])
+                            change_warnings.append(['Variable {} has warnings.'.format(variable_id), variable_warnings])
 
                     temp_errors, temp_warnings = validate_calculation(change)
                     change_errors.extend(temp_errors)
@@ -511,13 +570,13 @@ def validate_doc(doc, working_dir, validate_semantics=True,
 
                     if change_warnings:
                         change_id = '`' + change.id + '`' if change and change.id else str(i_change + 1)
-                        all_change_warnings.append(['Change {} may be invalid.'.format(change_id), change_warnings])
+                        all_change_warnings.append(['Change {} has warnings.'.format(change_id), change_warnings])
 
                 if all_change_errors:
                     task_errors[task]['other'].append(['Changes are invalid.', all_change_errors])
 
                 if all_change_warnings:
-                    task_warnings[task]['other'].append(['Changes may be invalid.', all_change_warnings])
+                    task_warnings[task]['other'].append(['Changes has warnings.', all_change_warnings])
 
         # repeated tasks involve 1 model
         if not subtasks_cyclic:
@@ -537,34 +596,9 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                 errors.append(['Task {} is invalid.'.format(task_id), task_errors[task]['other']])
 
             if task_warnings[task]['other']:
-                warnings.append(['Task {} may be invalid.'.format(task_id), task_warnings[task]['other']])
+                warnings.append(['Task {} has warnings.'.format(task_id), task_warnings[task]['other']])
 
         # validate data generators
-        if validate_targets_with_model_sources:
-            model_etrees = {}
-            for model in doc.models:
-                if (
-                    model.language
-                    and is_model_language_encoded_in_xml(model.language)
-                    and model.source
-                    and not model.source.startswith('#')
-                    and not model.source.startswith('urn:')
-                    and not model.source.startswith('http://')
-                    and not model.source.startswith('https://')
-                ):
-                    if os.path.isabs(model.source):
-                        model_source = model.source
-                    else:
-                        model_source = os.path.join(working_dir, model.source)
-
-                    if os.path.isfile(model_source):
-                        try:
-                            model_etrees[model] = lxml.etree.parse(model_source)
-                        except Exception:
-                            pass
-        else:
-            model_etrees = None
-
         for i_data_gen, data_gen in enumerate(doc.data_generators):
             data_gen_errors, data_gen_warnings = validate_data_generator(
                 data_gen, model_etrees=model_etrees, validate_targets_with_model_sources=validate_targets_with_model_sources)
@@ -575,7 +609,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                 errors.append(['Data generator {} is invalid.'.format(data_gen_id), data_gen_errors])
 
             if data_gen_warnings:
-                warnings.append(['Data generator {} may be invalid.'.format(data_gen_id), data_gen_warnings])
+                warnings.append(['Data generator {} has warnings.'.format(data_gen_id), data_gen_warnings])
 
         # validate outputs
         for i_output, output in enumerate(doc.outputs):
@@ -587,7 +621,7 @@ def validate_doc(doc, working_dir, validate_semantics=True,
                 errors.append(['Output {} is invalid.'.format(output_id), output_errors])
 
             if output_warnings:
-                warnings.append(['Output {} may be invalid.'.format(output_id), output_warnings])
+                warnings.append(['Output {} has warnings.'.format(output_id), output_warnings])
 
         # tasks, data generators that don't contribute to outputs
         used_data_generators = set()
@@ -697,6 +731,92 @@ def validate_unique_ids(doc):
     return errors
 
 
+def is_valid_color(color):
+    """ Determine if a color is valid
+
+    Args:
+        color (:obj:`str`): color
+
+    Returns:
+        :obj:`bool`: whether the color is valid
+    """
+    return re.match(r'^([a-f0-9]{6,6}|[a-f0-9]{8,8})$', color, re.IGNORECASE) is not None
+
+
+def validate_style(style):
+    """ Validate a style
+
+    Args:
+        style (:obj:`Style`): style
+
+    Returns:
+        :obj:`tuple`:
+
+            * nested :obj:`list` of :obj:`str`: nested list of errors (e.g., required ids missing or ids not unique)
+            * nested :obj:`list` of :obj:`str`: nested list of warnings (e.g., required ids missing or ids not unique)
+    """
+    errors = []
+    warnings = []
+
+    if style.line:
+        if style.line.type is not None and not isinstance(style.line.type, LineStyleType):
+            errors.append(['Line type must be one of the following', [[type] for type in sorted(LineStyleType.__members__.keys())]])
+
+        if style.line.color is not None and not is_valid_color(style.line.color):
+            errors.append(['Line color must be a 6 or 8-digit hexidecimal number, not `{}`'.format(style.line.color)])
+
+        if style.line.thickness is not None and style.line.thickness < 0:
+            errors.append(['Line thickness must be a non-negative number or NaN'])
+
+    if style.marker:
+        if style.marker.type is not None and not isinstance(style.marker.type, MarkerStyleType):
+            errors.append(['Marker type must be one of the following', [[type] for type in sorted(MarkerStyleType.__members__.keys())]])
+
+        if style.marker.size is not None and style.marker.size < 0:
+            errors.append(['Marker size must be a non-negative number or NaN'])
+
+        if style.marker.fill_color is not None and not is_valid_color(style.marker.fill_color):
+            errors.append(['Marker fill color must be a 6 or 8-digit hexidecimal number, not `{}`'.format(style.marker.fill_color)])
+
+        if style.marker.line_color is not None and not is_valid_color(style.marker.line_color):
+            errors.append(['Marker line color must be a 6 or 8-digit hexidecimal number, not `{}`'.format(style.marker.line_color)])
+
+        if style.marker.line_thickness is not None and style.marker.line_thickness < 0:
+            errors.append(['Marker line thickness must be a non-negative number or NaN'])
+
+    if style.fill:
+        if style.fill.color is not None and not is_valid_color(style.fill.color):
+            errors.append(['Fill color must be a 6 or 8-digit hexidecimal number, not `{}`'.format(style.fill.color)])
+
+    return (errors, warnings)
+
+
+def validate_base_style_network(styles):
+    """ Validate that the network of relationships among styles is acyclic
+
+    Args:
+        styles (:obj:`list` of :obj:`Style): styles
+
+    Returns:
+        nested :obj:`list` of :obj:`str`: nested list of errors (e.g., required ids missing or ids not unique)
+    """
+    style_base_graph = networkx.DiGraph()
+
+    for style in styles:
+        if style.id:
+            style_base_graph.add_node(style.id)
+
+    for style in styles:
+        if style.id and style.base and style.base.id:
+            style_base_graph.add_edge(style.id, style.base.id)
+
+    try:
+        networkx.algorithms.cycles.find_cycle(style_base_graph)
+        return [['The bases of the styles are defined cyclically. The bases of the styles must be acyclic.']]
+    except networkx.NetworkXNoCycle:
+        return []
+
+
 def validate_task(task):
     """ Validate a simulation task
 
@@ -749,7 +869,8 @@ def validate_repeated_task_has_one_model(task):
     return (errors, warnings)
 
 
-def validate_model(model, model_ids, working_dir, validate_models_with_languages=True, config=None):
+def validate_model(model, model_ids, working_dir, validate_models_with_languages=True, config=None,
+                   check_in_model_source=True, model_etree=None):
     """ Check a model
 
     Args:
@@ -780,11 +901,12 @@ def validate_model(model, model_ids, working_dir, validate_models_with_languages
     warnings.extend(tmp_warnings)
 
     # validate that model changes have targets
-    model_change_errors, model_change_warnings = validate_model_changes(model)
+    model_change_errors, model_change_warnings = validate_model_changes(
+        model, check_in_model_source=check_in_model_source, model_etree=model_etree)
     if model_change_errors:
         errors.append(['The changes of the model are invalid.', model_change_errors])
     if model_change_warnings:
-        warnings.append(['The changes of the model may be invalid.', model_change_warnings])
+        warnings.append(['The changes of the model have warnings.', model_change_warnings])
 
     return (errors, warnings)
 
@@ -873,7 +995,7 @@ def validate_model_source(model, model_ids, working_dir, validate_models_with_la
             if model_source_errors:
                 errors.append(['The model file `{}` is invalid.'.format(model.source), model_source_errors])
             if model_source_warnings:
-                warnings.append(['The model file `{}` may be invalid.'.format(model.source), model_source_warnings])
+                warnings.append(['The model file `{}` has warnings.'.format(model.source), model_source_warnings])
 
     return (errors, warnings)
 
@@ -952,7 +1074,7 @@ def validate_model_change_types(changes, types=(ModelChange, )):
     return errors
 
 
-def validate_model_changes(model):
+def validate_model_changes(model, check_in_model_source=True, model_etree=None):
     """ Check that model changes are semantically valid
 
     * Check that the variables of compute model changes are valid
@@ -974,7 +1096,10 @@ def validate_model_changes(model):
             if model.language:
                 temp_errors, temp_warnings = validate_target(change.target, change.target_namespaces,
                                                              ModelChange, model.language, model.id,
-                                                             check_in_model_source=False)
+                                                             check_in_model_source=check_in_model_source,
+                                                             model_change=model.has_structural_changes(),
+                                                             warn_xpaths_not_validated=False,
+                                                             model_etree=model_etree)
                 change_errors.extend(temp_errors)
                 change_warnings.extend(temp_warnings)
 
@@ -1007,7 +1132,9 @@ def validate_model_changes(model):
                     temp_errors, temp_warnings = validate_target(
                         variable.target, variable.target_namespaces,
                         Calculation, variable.model.language, variable.model.id,
-                        check_in_model_source=False)
+                        check_in_model_source=check_in_model_source,
+                        model_change=variable.model.has_structural_changes(),
+                        model_etree=model_etree)
                     variable_errors.extend(temp_errors)
                     variable_warnings.extend(temp_warnings)
 
@@ -1017,19 +1144,23 @@ def validate_model_changes(model):
 
                 if variable_warnings:
                     var_id = '`' + variable.id + '`' if variable and variable.id else str(i_variable + 1)
-                    change_warnings.append(['Variable {} may be invalid.'.format(var_id), variable_warnings])
+                    change_warnings.append(['Variable {} has warnings.'.format(var_id), variable_warnings])
 
             temp_errors, temp_warnings = validate_calculation(change)
             change_errors.extend(temp_errors)
             change_warnings.extend(temp_warnings)
 
+        elif isinstance(change, ModelAttributeChange):
+            if not change.new_value:
+                change_errors.append(['A ChangeAttribute must define a new value.'])
+
         if change_errors:
             change_id = '`' + change.id + '`' if change and change.id else str(i_change + 1)
             errors.append(['Change {} is invalid.'.format(change_id), change_errors])
 
         if change_warnings:
             change_id = '`' + change.id + '`' if change and change.id else str(i_change + 1)
-            warnings.append(['Change {} may be invalid.'.format(change_id), change_warnings])
+            warnings.append(['Change {} has warnings.'.format(change_id), change_warnings])
 
     return errors, warnings
 
@@ -1217,8 +1348,8 @@ def validate_data_generator(data_generator, model_etrees=None, validate_targets_
         if not param.id:
             errors.append(['Parameter {} must have an id.'.format(i_parameter + 1)])
 
-    temp_errors, temp_warnings = validate_data_generator_variables(data_generator.variables, model_etrees=model_etrees,
-                                                                   validate_targets_with_model_sources=validate_targets_with_model_sources)
+    temp_errors, temp_warnings = validate_data_generator_variables(
+        data_generator.variables, model_etrees=model_etrees, validate_targets_with_model_sources=validate_targets_with_model_sources)
     errors.extend(temp_errors)
     warnings.extend(temp_warnings)
 
@@ -1269,15 +1400,13 @@ def validate_data_generator_variables(variables, model_etrees=None, validate_tar
             models = get_models_referenced_by_task(variable.task)
             for model in models:
                 if model and model.language:
-                    model_changes = model.changes or list(filter(lambda change: change.model == model,
-                                                                 get_model_changes_for_task(variable.task)))
-
                     temp_errors, temp_warnings = validate_target(
                         variable.target, variable.target_namespaces,
                         DataGenerator, model.language,
                         model_id=model.id,
                         model_etree=model_etrees.get(model, None),
-                        check_in_model_source=not model_changes and validate_targets_with_model_sources)
+                        check_in_model_source=validate_targets_with_model_sources,
+                        model_change=model.has_structural_changes())
                     variable_errors.extend(temp_errors)
                     variable_warnings.extend(temp_warnings)
 
@@ -1287,7 +1416,7 @@ def validate_data_generator_variables(variables, model_etrees=None, validate_tar
 
         if variable_warnings:
             variable_id = '`' + variable.id + '`' if variable and variable.id else str(i_variable + 1)
-            warnings.append(['Variable {} may be invalid.'.format(variable_id), variable_warnings])
+            warnings.append(['Variable {} has warnings.'.format(variable_id), variable_warnings])
 
     if len(task_types) > 1:
         warnings.append(['The variables do not have consistent shapes.'])
@@ -1403,7 +1532,7 @@ def validate_output(output):
                 errors.append(['Curve {} is invalid.'.format(curve_id), curve_errors])
             if curve_warnings:
                 curve_id = '`' + curve.id + '`' if curve and curve.id else str(i_curve + 1)
-                warnings.append(['Curve {} may be invalid.'.format(curve_id), curve_warnings])
+                warnings.append(['Curve {} has warnings.'.format(curve_id), curve_warnings])
 
         if len(x_scales) > 1:
             warnings.append(['Curves do not have consistent x-scales.'])
@@ -1464,7 +1593,7 @@ def validate_output(output):
                 errors.append(['Surface {} is invalid.'.format(surface_id), surface_errors])
             if surface_warnings:
                 surface_id = '`' + surface.id + '`' if surface and surface.id else str(i_surface + 1)
-                warnings.append(['Surface {} may be invalid.'.format(surface_id), surface_warnings])
+                warnings.append(['Surface {} has warnings.'.format(surface_id), surface_warnings])
 
         if len(x_scales) > 1:
             warnings.append(['Surfaces do not have consistent x-scales.'])
@@ -1480,15 +1609,16 @@ def validate_output(output):
 
     if involves_repeated_task:
         msg = (
-            'Some simulation tools will not be able to generate this output because it uses data from repeated tasks. '
-            'Output for repeated tasks is an experimental feature of SED-ML, which is not officially supported.'
+            'Some simulation tools will not be able to generate this output because it uses data from repeated tasks, '
+            'which some simulation tools do not have the capability to execute.'
         )
         warnings.append([msg])
 
     return (errors, warnings)
 
 
-def validate_target(target, namespaces, context, language, model_id, model_etree=None, doc=None, check_in_model_source=False):
+def validate_target(target, namespaces, context, language, model_id, model_etree=None, doc=None,
+                    check_in_model_source=False, warn_xpaths_not_validated=True, model_change=False):
     """ Validate that a target is a valid XPath and that the namespaces needed to resolve a target are defined
 
     Args:
@@ -1500,6 +1630,8 @@ def validate_target(target, namespaces, context, language, model_id, model_etree
         model_etree (:obj:`etree.Element`, optional): XML element tree for model source
         doc (:obj:`SedDocument`, optional): SED document
         check_in_model_source (:obj:`bool`, optional): whether to check that the target exists in the source
+        warn_xpaths_not_validated (:obj:`bool`, optional): whether to warn that XPaths cannot be validated
+        model_changes (:obj:`bool`, optional): whether the model has changes that could validate or invalidate XPaths.
 
     Returns:
         nested :obj:`list` of :obj:`str`: nested list of errors (e.g., required ids missing or ids not unique)
@@ -1535,7 +1667,7 @@ def validate_target(target, namespaces, context, language, model_id, model_etree
             try:
                 xpath.evaluate(root)
 
-                if model_etree and check_in_model_source and context in [DataGenerator, Calculation]:
+                if model_etree and check_in_model_source:
                     if context == DataGenerator and '/@' in target:
                         xpath = target.rpartition('/@')[0]
                     else:
@@ -1543,13 +1675,28 @@ def validate_target(target, namespaces, context, language, model_id, model_etree
 
                     objs = eval_xpath(model_etree, xpath, namespaces)  # TODO
 
-                    if not objs:
-                        errors.append(['XPath `{}` does not match any elements of model `{}`.'.format(xpath, model_id or '')])
-                    elif len(objs) > 1:
-                        errors.append(['XPath `{}` matches multiple elements of model `{}`.'.format(xpath, model_id or '')])
+                    if model_change:
+                        if not objs:
+                            msg = (
+                                'XPath `{}` does not match any elements of model `{}`.  However, one or more model change '
+                                'objects may be intended to correct this failure.'
+                            ).format(xpath, model_id or '')
+                            warnings.append([msg])
+                        elif len(objs) > 1:
+                            msg = (
+                                'XPath `{}` matches multiple elements of model `{}`.  However, one or more model change '
+                                'objects may be intended to correct this failure.'
+                            ).format(xpath, model_id or '')
+                            warnings.append([msg])
+                    else:
+                        if not objs:
+                            errors.append(['XPath `{}` does not match any elements of model `{}`.'.format(xpath, model_id or '')])
+                        elif len(objs) > 1:
+                            errors.append(['XPath `{}` matches multiple elements of model `{}`.'.format(xpath, model_id or '')])
 
                 else:
-                    warnings.append(['XPath could not be validated.'])
+                    if warn_xpaths_not_validated:
+                        warnings.append(['XPath could not be validated.'])
 
             except lxml.etree.XPathEvalError as exception:
                 if 'Undefined namespace prefix' in str(exception):
