@@ -46,12 +46,21 @@ def exec_sedml_docs_in_archive_with_simulator_cli(archive_filename, out_dir, sim
         raise RuntimeError("The command '{}' could not be found".format(simulator_command))
 
     except subprocess.CalledProcessError as exception:
-        raise RuntimeError("The command '{}' could not execute the archive:\n\n  {}".format(
-            simulator_command, exception.stderr.replace('\n', '\n  ')))
+        msg = "The command '{}' could not execute the archive{}".format(
+            simulator_command,
+            ':\n\n  ' + exception.stderr.replace('\n', '\n  ')
+            if exception.stderr else
+            '.'
+        )
+        raise RuntimeError(msg)
 
     except Exception as exception:
-        raise RuntimeError("The command '{}' could not execute the archive:\n\n  {}".format(
-            simulator_command, str(exception).replace('\n', '\n  ')))
+        raise RuntimeError("The command '{}' could not execute the archive{}".format(
+            simulator_command,
+            ':\n\n  ' + str(exception).replace('\n', '\n  '))
+            if str(exception) else
+            '.'
+        )
 
 
 def exec_sedml_docs_in_archive_with_containerized_simulator(
@@ -97,7 +106,8 @@ def exec_sedml_docs_in_archive_with_containerized_simulator(
     # run image
     in_dir = tempfile.mkdtemp()
     if os.path.isfile(archive_filename):
-        shutil.copyfile(archive_filename, os.path.join(in_dir, os.path.basename(archive_filename)))
+        copy_archive_filename = os.path.join(in_dir, os.path.basename(archive_filename))
+        shutil.copyfile(archive_filename, copy_archive_filename)
 
     if not os.path.isdir(out_dir):
         os.makedirs(out_dir)
@@ -119,6 +129,7 @@ def exec_sedml_docs_in_archive_with_containerized_simulator(
             if os.name == 'posix':
                 args.extend(['--user', str(os.getuid())])
             else:
+                shutil.rmtree(in_dir)
                 raise NotImplementedError('The current user id can only be retrieved for POSIX OSes')
         elif user_to_exec_within_container == '_SUDO_':
             args.insert(0, 'sudo')
